<?php

namespace app\controllers;

use Yii;
use app\models\Design;
use app\models\DesignSearch;
use app\models\UploadForm;
use yii\web\Controller;
use yii\web\NotFoundHttpException;
use yii\filters\VerbFilter;
use yii\web\UploadedFile;
use yii\filters\AccessControl;


/**
 * DesignController implements the CRUD actions for Design model.
 */
class DesignController extends Controller
{
    /**
     * @inheritDoc
     */
    // public function behaviors()
    // {
    //     return array_merge(
    //         parent::behaviors(),
    //         [
    //             'verbs' => [
    //                 'class' => VerbFilter::className(),
    //                 'actions' => [
    //                     'delete' => ['POST'],
    //                 ],
    //             ],
    //         ]
    //     );
    // }

    public function behaviors()
    {
        return [
            'access' => [
                'class' => AccessControl::className(),
                'rules' => [
                    [
                        'actions' => ['login', 'error'],
                        'allow' => true,
                    ],
                    [
                        'actions' => [
                            'index',
                            'my-uploads',
                            'create',
                            'view',
                            'update',
                            'delete',
                            'remove'
                        ],
                        'allow' => true,
                        'roles' => ['@'],
                    ],
                ],
            ],
            'verbs' => [
                'class' => VerbFilter::className(),
                'actions' => [
                    'logout' => ['post'],
                ],
            ],
        ];
    }

    /**
     * Lists all Design models.
     * @return mixed
     */
    public function actionIndex()
    {
        $searchModel = new DesignSearch();
        $dataProvider = $searchModel->search($this->request->queryParams);

        return $this->render('index', [
            'searchModel' => $searchModel,
            'dataProvider' => $dataProvider,
        ]);
    }

    /**
     * Lists all Design models.
     * @return mixed
     */
    public function actionMyUploads()
    {
        $searchModel = new DesignSearch();
        $searchModel->user_id = Yii::$app->user->identity->id;
        $dataProvider = $searchModel->search($this->request->queryParams);
        // echo '<pre>'; print_r($userId); echo '</pre>';
        // echo '<pre>'; print_r($searchModel->attributes); echo '</pre>';
        // exit;
        return $this->render('index', [
            'searchModel' => $searchModel,
            'dataProvider' => $dataProvider,
        ]);
    }

    /**
     * Displays a single Design model.
     * @param int $id ID
     * @return mixed
     * @throws NotFoundHttpException if the model cannot be found
     */
    public function actionView($id)
    {
        return $this->render('view', [
            'model' => $this->findModel($id),
        ]);
    }

    /**
     * Creates a new Design model.
     * If creation is successful, the browser will be redirected to the 'view' page.
     * @return mixed
     */
    public function actionCreate()
    {
        $model = new Design();
        $fileUpload = new UploadForm();

        // echo "<pre>"; print_r($model->loadDefaultValues()->attributes); echo "</pre>";
        // echo "<pre>"; print_r($model->attributes); echo "</pre>"; exit;
        if ($this->request->isPost) {
            $model->user_id = Yii::$app->user->identity->id;
            $model->created_at = $model->updated_at = date('Y-m-d H:i:s');
            $model->created_by = $model->updated_by = $model->user_id;
            if ($model->load(Yii::$app->request->post()) && $model->save()) {
                $fileUpload->img = UploadedFile::getInstance($fileUpload, 'img');
                $fileUpload->file = UploadedFile::getInstance($fileUpload, 'file');
                $fileUpload->pdf = UploadedFile::getInstance($fileUpload, 'pdf');
                
                if ($uploadedPath = $fileUpload->upload($model, 'img')) {
                    $model->design_img = $uploadedPath;
                    $model->save();
                }
                if ($uploadedPath = $fileUpload->upload($model, 'file')) {
                    $model->design_file = $uploadedPath;
                    $model->save();
                }
                if ($uploadedPath = $fileUpload->upload($model, 'pdf')) {
                    $model->design_pdf = $uploadedPath;
                    $model->save();
                }
                // echo "<pre>"; print_r($model->attributes); echo "</pre>"; exit;
                return $this->redirect(['view', 'id' => $model->id]);
            }
        } else {
            $model->loadDefaultValues();
        }

        return $this->render('create', [
            'model' => $model,
            'fileUpload' => $fileUpload,
        ]);
    }

    /**
     * Updates an existing Design model.
     * If update is successful, the browser will be redirected to the 'view' page.
     * @param int $id ID
     * @return mixed
     * @throws NotFoundHttpException if the model cannot be found
     */
    public function actionUpdate($id)
    {
        $model = $this->findModel($id);
        $fileUpload = new UploadForm();
        
        if ($this->request->isPost) {
            $model->updated_at = date('Y-m-d H:i:s');
            $model->updated_by = Yii::$app->user->identity->id;
            if ($model->load(Yii::$app->request->post()) && $model->save()) {
                $fileUpload->img = UploadedFile::getInstance($fileUpload, 'img');
                $fileUpload->file = UploadedFile::getInstance($fileUpload, 'file');
                $fileUpload->pdf = UploadedFile::getInstance($fileUpload, 'pdf');
                
                if ($uploadedPath = $fileUpload->upload($model, 'img')) {
                    $model->design_img = $uploadedPath;
                    $model->save();
                }
                if ($uploadedPath = $fileUpload->upload($model, 'file')) {
                    $model->design_file = $uploadedPath;
                    $model->save();
                }
                if ($uploadedPath = $fileUpload->upload($model, 'pdf')) {
                    $model->design_pdf = $uploadedPath;
                    $model->save();
                }
                // echo "<pre>"; print_r($model->attributes); echo "</pre>"; exit;
                return $this->redirect(['view', 'id' => $model->id]);
            }
        }

        return $this->render('update', [
            'model' => $model,
            'fileUpload' => $fileUpload,
        ]);
    }

    /**
     * Deletes an existing Design model.
     * If deletion is successful, the browser will be redirected to the 'index' page.
     * @param int $id ID
     * @return mixed
     * @throws NotFoundHttpException if the model cannot be found
     */
    public function actionDelete($id)
    {
        $model = $this->findModel($id);
        $model->is_deleted = 1;
        // echo '<pre>'; print_r($model->attributes); echo '</pre>'; exit;
        // $this->findModel($id)->delete();
        $model->save();
        return $this->redirect(['my-uploads']);
    }

    public function actionRemove($id, $type)
    {
        $model = $this->findModel($id);
        $model->design_img = $type === 'img' ? '' : $model->design_img;
        $model->design_file = $type === 'file' ? '' : $model->design_file;
        $model->design_pdf = $type === 'pdf' ? '' : $model->design_pdf;
        $model->save();
        return $this->redirect(['update', 'id' => $model->id]);
    }

    /**
     * Finds the Design model based on its primary key value.
     * If the model is not found, a 404 HTTP exception will be thrown.
     * @param int $id ID
     * @return Design the loaded model
     * @throws NotFoundHttpException if the model cannot be found
     */
    protected function findModel($id)
    {
        if (($model = Design::findOne($id)) !== null) {
            return $model;
        }

        throw new NotFoundHttpException('The requested page does not exist.');
    }
}
